# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.1] - 2025-03-21
### Added
- `word_stemmer` module
- `tokenizer` module
- `p2t` module
- `pos_tagger` module
- `POSTaggerRuleBased` class
- `POSTagger` class


[Unreleased]: https://github.com/openscilab/parsipy/compare/v0.1...dev
[0.1]: https://github.com/openscilab/parsipy/compare/277cd75...v0.1